summaryrefslogtreecommitdiff
path: root/sd/source/ui/inc/taskpane/TitledControl.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/inc/taskpane/TitledControl.hxx')
-rwxr-xr-xsd/source/ui/inc/taskpane/TitledControl.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/sd/source/ui/inc/taskpane/TitledControl.hxx b/sd/source/ui/inc/taskpane/TitledControl.hxx
index cb7cd3b2159c..550cb54d888b 100755
--- a/sd/source/ui/inc/taskpane/TitledControl.hxx
+++ b/sd/source/ui/inc/taskpane/TitledControl.hxx
@@ -96,7 +96,7 @@ public:
TitleBar* GetTitleBar (void);
/** Return the control child. When a control factory has been given and
- the control has not yet been created and the given flag is <TRUE/>
+ the control has not yet been created and the given flag is <sal_True/>
then the control is created.
*/
TreeNode* GetControl (void);
@@ -109,13 +109,13 @@ public:
higher level expand command. You may want to use
ExpandViaContainer() instead.
@param bExpanded
- When <TRUE/> then the control is expanded, otherwise it is
+ When <sal_True/> then the control is expanded, otherwise it is
collapsed.
*/
virtual bool Expand (bool bExpanded = true);
- /** Return whether the control is currently expanded (<TRUE/>) or
- not (<FALSE/>).
+ /** Return whether the control is currently expanded (<sal_True/>) or
+ not (<sal_False/>).
*/
virtual bool IsExpanded (void) const;